Table of gear types available in PacFIN data

GearTable

Format

A data frame with 65 rows and 6 columns

TYPE

A numeric

PACFIN_GEAR_CODE

A three letter character string denoting the gear type

GRID

A three letter character string denoting the gear type

GROUP

A three letter character string that groups gear type into general groups

SHORT

Character string describing the gear type

DESCRIPTION

Character string describing the gear type