Save several figures to your computer that summarize the composition samples that are available for the given species. None of the figures are meant to be included in the stock assessment document, but rather, are for exploring the data.

plotCleaned(Pdata, savedir)

Arguments

Pdata

A data object created using cleanPacFIN()].

savedir

Directory where output will be saved. The directory where the file should be saved.

Value

The following figures are saved to savedir:

  • PacFIN_comp_Nbystate.png

  • PacFIN_comp_distributions.png

  • PacFIN_comp_NbyGRID.png

  • PacFIN_comp_depth.png

  • PacFIN_comp_geargroup.png

  • PacFIN_comp_INPFC.png

  • PacFIN_comp_lengthvage.png

See also

This function is called by cleanPacFIN and heavily relies on getGearGroup to create gear categories.

Author

Andi Stephens, Kelli F. Johnson