Create a table of samples by fleet and year to be included in an assessment document.

tableSample(
  Pdata,
  stratification.cols = c("state", "geargroup"),
  savedir = NULL,
  verbose = TRUE,
  comps = lifecycle::deprecated(),
  remove_yrs = lifecycle::deprecated(),
  fname = lifecycle::deprecated(),
  strat = lifecycle::deprecated()
)

Arguments

Pdata

A data frame returned from cleanPacFIN(), nwfscSurvey::get_expanded_comps(), getExpansion_1(), getExpansion_2, or getComps(). If a data frame returned from getComps() is provided a table of samples by year and fleet with trips, samples, and input sample sizes will be returned. If a data frame returned from the other functions listed, a table of samples by year and stratification.cols for lengths and ages will be returned.

stratification.cols

Columns in Pdata to summarize the data for the calculation of samples sizes. These columns are not used in the data frame is from getComps() because the grouping structure is already set in that data frame.

savedir

A file path to the directory where the results will be saved. The default is NULL.

verbose

A logical specifying if output should be written to the screen or not. Good for testing and exploring your data but can be turned off when output indicates information that you already know. The printing of output to the screen does not affect any of the returned objects. The default is to always print to the screen, i.e., verbose = TRUE.

comps

Deprecated. Specify whether to calculate the length or Age samples. The default is to calculate the number of length samples.

remove_yrs

Deprecated. A vector of years to remove from the data before summarizing sample sizes. The default of NULL leads to no sub setting of the data.

fname

Deprecated. A filename with the appropriate extension, used to save the function output to the disk. Full, relative, or simple paths are allowed because the argument is used as is, i.e., not redirected to a directory different than getwd().

strat

Deprecated. A vector of column names to stratify the output over. For example, if you wish to summarize by ageing method, then the argument would look like strat = "agemethod" or, if you want to look at fleets and gear, strat = c("fleet", "usegear").

Value

A data frame is returned of samples by year

Author

Chantel R. Wetzel