GearTable.RdTable of gear types available in PacFIN data
GearTableA data frame with 65 rows and 6 columns
A numeric
A three letter character string denoting the gear type
A three letter character string denoting the gear type
A three letter character string that groups gear type into general groups
Character string describing the gear type
Character string describing the gear type