get_codelist.RdGet a data frame with options available in PacFIN and their descriptions.
PacFIN documentation refers to these data frames as code_lists, thus the
function name get_codelist helps explain what we are getting.
get_codelist(x = c("GEAR", "INPFC", "PORT"))A data frame with the following potential columns, where the column names are always in all caps:
integer value of 1 (gear code), 2 (gear group), or 3 (all)
three letter grid or gear type code
three letter gear grouping code
mapping of sub area to areas
International North Pacific Fisheries Commission (INPFC) Area code used in PacFIN
classification of tree structure, i.e., if it is a subarea
the management council that the area falls within
character port code
agency code, e.g., "W" for Washington
numeric port code
short description
long, detailed description
S3: This is an S3 class object, of which I am not very familiar with. Thus, feel free to provide comments on the code or submit an issue if you have ideas or corrections.
source:
All PacFIN code lists
are publicly available. As time progresses, I hope to have all lists
available within R through code_lists. If you have time to add
any of this functionality, feel free to submit a pull request and
thank you in advance for collaborating.
availablegrids <- get_codelist("GEAR")
availableports <- get_codelist("PORT")
availableinpfc <- get_codelist("INPFC")