get_latitude.RdAssign latitudes to records
get_latitude(Pdata, verbose = TRUE)A data frame returned from PullBDS.PacFIN() containing
biological samples. These data are stored in the Pacific Fishieries
Information Network (PacFIN) data warehouse, which originated in 2014 and
are pulled using sql calls.
A logical specifying if output should be written to the
screen or not. Good for testing and exploring your data but can be turned
off when output indicates information that you already know. The printing
of output to the screen does not affect any of the returned objects. The
default is to always print to the screen, i.e., verbose = TRUE.
The data frame is returned with an additional column for latitude